==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebSortingStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingStrategyDescription } from "./WebSortingStrategyDescription";
/**
 * @hidden
 */
export let WebSortingStrategyDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSortingStrategyDescriptionMetadata extends Base {
        static b(a) {
            if (WebSortingStrategyDescriptionMetadata.a == null) {
                WebSortingStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSortingStrategyDescriptionMetadata.c(WebSortingStrategyDescriptionMetadata.a);
            }
            if (a.j(WebSortingStrategyDescriptionMetadata.a)) {
                return;
            }
            a.y(WebSortingStrategyDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SortingStrategy");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
        }
        static d(a) {
            WebSortingStrategyDescriptionMetadata.b(a);
            a.aa("WebSortingStrategy", () => new WebSortingStrategyDescription());
            a.z("WebSortingStrategy", WebSortingStrategyDescriptionMetadata.a);
        }
    }
    WebSortingStrategyDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSortingStrategyDescriptionMetadata, 'WebSortingStrategyDescriptionMetadata');
    WebSortingStrategyDescriptionMetadata.a = null;
    return WebSortingStrategyDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebSortingStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingStrategyDescription } from "./WebSortingStrategyDescription";
/**
 * @hidden
 */
export let WebSortingStrategyDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSortingStrategyDescriptionMetadata extends Base {
        static b(a) {
            if (WebSortingStrategyDescriptionMetadata.a == null) {
                WebSortingStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSortingStrategyDescriptionMetadata.c(WebSortingStrategyDescriptionMetadata.a);
            }
            if (a.k(WebSortingStrategyDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebSortingStrategyDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SortingStrategy");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebSortingStrategyDescriptionMetadata.b(a);
            a.ac("WebSortingStrategy", () => new WebSortingStrategyDescription());
            a.ab("WebSortingStrategy", WebSortingStrategyDescriptionMetadata.a);
        }
    }
    WebSortingStrategyDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSortingStrategyDescriptionMetadata, 'WebSortingStrategyDescriptionMetadata');
    WebSortingStrategyDescriptionMetadata.a = null;
    return WebSortingStrategyDescriptionMetadata;
})();
